# Skew-T Distribution (Fernandez & Steel)

This package provides a Python implementation of the skewed Student's t-distribution as proposed by Fernandez and Steel (1998). It is created as a `scipy.stats` compatible continuous random variable.

## Installation

```bash
pip install skewt-fs